module UU
  module OS
    module Util

      # Module providing methods for URL conversions and manipulation.
      # @private
      module URLConverter # :nodoc:

        # Concatenates path elements so there is exactly one '/' between elements.
        # @param [Array<String>] path_elements Path elements.
        # @return [String] Concatenated path.
        def concat_path(*path_elements)
          URLConverter.concat_path(*path_elements)
        end

        # @see #concat_path
        # @private
        def self.concat_path(*path_elements) # :nodoc:
          return '' if path_elements.size == 0
          path = path_elements[0].to_s.dup
          path_elements.drop(1).each do |part|
            part = part.to_s
            next if part.empty?
            if (path[-1] == '/') ^ (part[0] == '/')
              # path ends with '/' xor part starts with '/'
              path << part
            elsif (path[-1] == '/') && (part[0] == '/')
              # path ends with '/' and part starts with '/'
              path << part[1..-1]
            else
              # path does not end with '/' and part does not start with '/'
              path << '/' << part
            end
          end
          # remove trailing slash
          path = path[0..-2] if path[-1] == '/'
          return path
        end

      end

    end
  end
end
